# Datasets

The default datasets supported by the AIF 360 toolkit are listed below. Please note that the raw data files are NOT provided with the toolkit. Please follow the instructions given for each dataset in its corresponding README file


1. Adult / Census Income 

   Source: <a href="https://archive.ics.uci.edu/ml/datasets/adult">https://archive.ics.uci.edu/ml/datasets/adult</a>

   Download instructions: See [raw/adult/README.md](raw/adult/README.md)

2. German Credit Data 

   Source: <a href="https://archive.ics.uci.edu/ml/datasets/Statlog+%28German+Credit+Data%29">https://archive.ics.uci.edu/ml/datasets/Statlog+%28German+Credit+Data%29</a>

   Download instructions: See [raw/german/README.md](raw/german/README.md)

3. ProPublica Recidivism/COMPAS 

   Source: <a href="https://github.com/propublica/compas-analysis">https://github.com/propublica/compas-analysis</a>

   Download instructions: See [raw/compas/README.md](raw/compas/README.md)

4. Bank marketing 

   Source: <a href="https://archive.ics.uci.edu/ml/datasets/Bank+Marketing">https://archive.ics.uci.edu/ml/datasets/Bank+Marketing</a>

   Download instructions: See [raw/bank/README.md](raw/bank/README.md)

5. Medical Expenditure Panel Survey Data

   Source: <a href="https://meps.ahrq.gov/mepsweb/"><https://meps.ahrq.gov/mepsweb/></a>
   
   Download instructions: See [raw/meps/README.md](raw/meps/README.md)
